#
# spec file for package python-mplcursors
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-mplcursors
Version:        0.5.3
Release:        2.2
Summary:        Interactive data selection cursors for Matplotlib
License:        Zlib
URL:            https://github.com/anntzer/mplcursors
Source:         https://files.pythonhosted.org/packages/source/m/mplcursors/mplcursors-%{version}.tar.gz
# PATCH-FIX-UPSTREAM mplcursors-10b553e-mpl3.9-pytest8.patch https://github.com/anntzer/mplcursors/commit/10b553e
Patch0:         mplcursors-10b553e-mpl3.9-pytest8.patch
# PATCH-FIX-UPSTREAM mplcursors-1d9461c-np2.patch https://github.com/anntzer/mplcursors/commit/1d9461c
Patch1:         mplcursors-1d9461c-np2.patch
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-matplotlib >= 3.1
%if 0%{?python_version_nodots} < 38
Requires:       python-importlib-metadata
%endif
Requires:       (python-matplotlib >= 3.1 without python-matplotlib = 3.7.1)
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module matplotlib >= 3.1 without %python-matplotlib = 3.7.1}
BuildRequires:  %{python_module importlib-metadata if %python-base < 3.8}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
mplcursors provides interactive data selection cursors for Matplotlib.

%prep
%setup -q -n mplcursors-%{version}
%autopatch -p1

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc CHANGELOG.rst README.rst
%license LICENSE.txt
%{python_sitelib}/mplcursors
%{python_sitelib}/mplcursors.pth
%{python_sitelib}/mplcursors-%{version}*-info

%changelog
* Sun Sep  1 2024 Ben Greiner <code@bnavigator.de>
- Make fit for new versions of Numpy, Matplotlib and Pytest
  * Add mplcursors-1d9461c-np2.patch
  * Add mplcursors-10b553e-mpl3.9-pytest8.patch
* Sun Feb  4 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.5.3
  * Require Python 3.7 (due to setuptools support ranges); mark
    Matplotlib 3.7.1 as incompatible.
  * Highlights can be removed by right-clicking anywhere on the
    highlighting artist, not only on the annotation.
- There was an otherwise unmentioned license change
- Drop mplcursors-fix-stem-api.patch
* Fri Dec 29 2023 Ben Greiner <code@bnavigator.de>
- Add mplcursors-fix-stem-api.patch, fixing API change in
  Matplotlib 3.8
* Mon Jan  9 2023 Ben Greiner <code@bnavigator.de>
- Update to v0.5.2
  * Fix compatibility with Matplotlib 3.6 and with PEP517 builds.
  * Non-multiple cursors can now be dragged.
* Thu Jan 20 2022 Ben Greiner <code@bnavigator.de>
- Update to v0.5.1
  * Breaking change: index is now a direct attribute of the
    Selection, rather than a sub-attribute via target.
    (Selection.target.index has been deprecated and will be removed
    in the future.)
  * Additional annotations are no longer created when dragging a
    multiple cursor.
  * Clicking on an annotation also updates the "current" selection
    for keyboard motion purposes.
  * Disabling a cursor also makes it unresponsive to motion keys.
  * Hovering is still active when the pan or zoom buttons are
    pressed (but not if there's a pan or zoom currently being
    selected).
  * Annotations are now matplotlib.figure.Figure-level artists,
    rather than Axes-level ones (so as to be drawn on top of
    twinned axes, if present).
* Fri Apr  9 2021 Ben Greiner <code@bnavigator.de>
- Update to v0.4
  * Invisible artists are now unpickable (patch suggested by
    @eBardieCT).
  * The bindings kwarg can require modifier keys for mouse button
    events.
  * Transient hovering (suggested by @LaurenceMolloy).
  * Switch to supporting only "new-style" (LineCollection) stem
    plots.
  * Cursors are drawn with zorder=np.inf.
- Drop patches merged upstream
  * mplcursors-unicodeminus.patch
  * mplcursors-newstem.patch
  * mplcursors-parse_annotation.patch
  * mplcursors-fix-LineCollection.patch
  * mplcursors-unicodeminus2.patch
- Skip python36: No python36-matplotlib in TW.
* Thu Jul 23 2020 Benjamin Greiner <code@bnavigator.de>
- moved Pillow requirement to matplotlib package
* Tue Jul 21 2020 Benjamin Greiner <code@bnavigator.de>
- allow newest pytest again
- require Pillow
- apply upstream patches to allow newest matplotlib and numpy
  gh#anntzer/mplcursors#26
  * mplcursors-unicodeminus.patch
  * mplcursors-newstem.patch
  * mplcursors-parse_annotation.patch
  * mplcursors-fix-LineCollection.patch
  * mplcursors-unicodeminus2.patch
* Tue Jun  9 2020 Dirk Mueller <dmueller@suse.com>
- build against older pytest to have tests passing
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Drop py2 dependencies from py3 only marked package
* Tue Jan  8 2019 Todd R <toddrme2178@gmail.com>
- initial version
